==> haskell-fsnotify0.3-0.3.0.1-154-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fsnotify0.3.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fsnotify
version:              0.3.0.1
visibility:           public
id:                   fsnotify-0.3.0.1-5Nu6I9SwA0iEqcCGYl0MTv
key:                  fsnotify-0.3.0.1-5Nu6I9SwA0iEqcCGYl0MTv
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage:             https://github.com/haskell-fswatch/hfsnotify
synopsis:             Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.

category:             Filesystem
abi:                  c1307b2486149012859ab241fd8c3384
exposed:              True
exposed-modules:      System.FSNotify System.FSNotify.Devel
hidden-modules:
    System.FSNotify.Listener System.FSNotify.Path
    System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux

import-dirs:          /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fsnotify0.3
hs-libraries:         HSfsnotify-0.3.0.1-5Nu6I9SwA0iEqcCGYl0MTv
depends:
    async-2.2.5-BF7r5QBBfU4psLNmWYED8 base-4.17.2.1 bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    hinotify-0.4.2-5TATrE45rRi98PpLrEoIRy
    shelly-1.11.0-2kMioXY5bQFSDNgXjk3s4 text-2.0.2 time-1.12.2
    unix-2.7.3 unix-compat-0.7.4-L2kjPBf5fIp84KOh8GLDxJ

haddock-interfaces:   /usr/share/doc/haskell-fsnotify0.3/html/fsnotify.haddock
haddock-html:         /usr/share/doc/haskell-fsnotify0.3/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fsnotify0.3-0.3.0.1-155-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fsnotify0.3.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fsnotify
version:              0.3.0.1
visibility:           public
id:                   fsnotify-0.3.0.1-7dw4cvJqX355hXNRk9w7qZ
key:                  fsnotify-0.3.0.1-7dw4cvJqX355hXNRk9w7qZ
license:              BSD-3-Clause
maintainer:           Tom McLaughlin <tom@codedown.io>
author:               Mark Dittmer <mark.s.dittmer@gmail.com>, Niklas Broberg
homepage:             https://github.com/haskell-fswatch/hfsnotify
synopsis:             Cross platform library for file change notification.
description:
    Cross platform library for file creation, modification,
    and deletion notification. This library builds upon
    existing libraries for platform-specific Windows, Mac,
    and Linux filesystem event notification.

category:             Filesystem
abi:                  a5b1d557f5ad366d15b67664a3612db3
exposed:              True
exposed-modules:      System.FSNotify System.FSNotify.Devel
hidden-modules:
    System.FSNotify.Listener System.FSNotify.Path
    System.FSNotify.Polling System.FSNotify.Types System.FSNotify.Linux

import-dirs:          /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fsnotify-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fsnotify0.3
hs-libraries:         HSfsnotify-0.3.0.1-7dw4cvJqX355hXNRk9w7qZ
depends:
    async-2.2.5-3On0Vdlc3urBKBpRPAboKf base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 directory-1.3.7.1
    filepath-1.4.2.2 hinotify-0.4.2-8A1dSQxRdzP3XgH6XktXiz
    shelly-1.11.0-35O2WDRB0boFbt1816K7X0 text-2.0.2 time-1.12.2
    unix-2.7.3 unix-compat-0.7.4-BDNMqGtORWv1TblmXvfCQe

haddock-interfaces:   /usr/share/doc/haskell-fsnotify0.3/html/fsnotify.haddock
haddock-html:         /usr/share/doc/haskell-fsnotify0.3/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
